@@ -3,12 +3,11 @@
 """Console script."""
 import click
 import shutil
+import os
+import pandas as pd
 from .parser import Parser
 from .output.csvmerger import CSVMerger
-import multiprocessing as mp
-import pandas as pd
-from .bobarun import *
-from .wrangler import get_universe_script, DIR_LOG
+from .bobarun import BobaRun
 
 
 @click.command()
@@ -17,7 +16,7 @@ from .wrangler import get_universe_script, DIR_LOG
 @click.option('--out', help='Output directory',
               default='.', show_default=True)
 @click.option('--lang', help='Language, can be python/R [default: inferred from file extension]',
-              default='')
+              default=None)
 def compile(script, out, lang):
     """Generate multiverse analysis from specifications."""
 
@@ -72,70 +71,21 @@ def run(folder, run_all, num, thru, jobs, batch_size):
 
     check_path(folder)
 
-    # get the names of all the universes we want to run
-    universes = []
-    data = pd.read_csv(folder + '/summary.csv')
-    vals = data['Filename'].to_list()
-    extension = Lang('', vals[0]).get_ext()
-    if run_all:
-        universes = vals
-    else:
+    df = pd.read_csv(folder + '/summary.csv')
+    num_universes = df.shape[0]
+
+    if not run_all:
         if thru == -1:
             thru = num
         if num < 1:
             print_help()
         if thru < num:
             print_help('The thru parameter cannot be less than the num parameter.')
-        if num >= len(vals) or thru >= len(vals):
-            print_help('There are only ' + str(len(vals)) + ' universes.')
+        if num > num_universes or thru > num_universes:
+            print_help(f'There are only {num_universes} universes.')
 
-        for i in range(num, thru + 1):
-            universe = get_universe_script(i, extension)
-            print(universe)
-            universes.append(universe)
-
-    run_commands_in_folder(folder, 'pre_exe.sh')
-
-    if jobs == 0:
-        jobs = mp.cpu_count()
-
-    if batch_size == 0:
-        batch_size = min(int(len(universes)**0.5), int(len(universes)/jobs) + 1)
-
-    pool = mp.Pool(jobs)
-
-    results = []
-
-    p_log = os.path.join(folder, DIR_LOG)
-    if os.path.exists(p_log):
-        shutil.rmtree(p_log)
-    os.makedirs(p_log)
-
-    with open(os.path.join(p_log, 'logs.csv'), 'w') as log:
-        log.write('universe,exit_code\n')
-
-    # callback that is run for each retrieved result.
-    def check_result(r):
-        results.extend(r)
-        # write the results to our logs
-        with open(os.path.join(p_log, 'logs.csv'), 'a') as f_log:
-            for res in r:
-                f_log.write(res[0] + ',' + str(res[1]) + '\n')
-
-
-    # run each batch of universes as a separate task
-    while universes:
-        batch = []
-        while universes and len(batch) < batch_size:
-            batch.append(universes.pop(0))
-
-        pool.apply_async(run_batch_of_universes, args=(folder, batch), callback=check_result)
-
-    # collect all the results
-    pool.close()
-    pool.join()
-
-    run_commands_in_folder(folder, 'post_exe.sh')
+    br = BobaRun(folder, jobs, batch_size)
+    br.run_from_cli(run_all, num, thru)
 
 
 @click.command()
