@@ -46,8 +46,9 @@ class Parser:
 
     """ Parse everything """
 
-    def __init__(self, f1, out='.', lang=''):
+    def __init__(self, f1, out='.', lang=None):
         self.fn_script = f1
+        self.parent_dir = out
         self.out = os.path.join(out, 'multiverse/')
 
         self.paths = []
@@ -68,7 +69,14 @@ class Parser:
 
         # init helper class
         try:
-            self.lang = Lang(lang, f1)
+            supported_langs = None
+            try:
+                with open(os.path.join(self.parent_dir, self.spec['lang']), 'r') as l:
+                    supported_langs = json.load(l)
+            except KeyError:
+                pass
+
+            self.lang = Lang(f1, lang=lang, supported_langs=supported_langs)
             self.wrangler = Wrangler(self.spec, self.lang, self.out)
         except LangError as e:
             self._throw(e.args[0])
@@ -296,6 +304,7 @@ class Parser:
         # write the pre and post execs to a file.
         self.wrangler.write_pre_exe()
         self.wrangler.write_post_exe()
+        self.wrangler.write_lang()
 
     @staticmethod
     def _nice_path(path):
