@@ -117,7 +117,8 @@ class Wrangler:
         if self.lang.is_r():
             return self._codegen_r()
         if self.lang.is_python():
-            return self._codegen_python()
+            return self._codegen_python()      
+        return ''
 
     def write_pre_exe(self):
         fn_pre_exec = os.path.join(self.out, 'pre_exe.sh')
@@ -129,6 +130,12 @@ class Wrangler:
         with open(fn_post_exec, 'w') as f:
             f.write(self.post_exe)
 
+    def write_lang(self):
+        lang = os.path.join(self.out, 'lang.json')
+        with open(lang, 'w') as f:
+            json.dump(self.lang.supported_langs, f)
+
+
     def write_universe(self, code):
         """Write the generated code to a universe file."""
 
